@@ -13,14 +13,15 @@
 # limitations under the License.
 
 from typing import List, Optional, Iterator
-from charset_normalizer import from_path
+from charset_normalizer import from_path, from_bytes
 from csv import DictReader
 from .AlitaTableLoader import AlitaTableLoader
 from typing import Any
 
 class AlitaCSVLoader(AlitaTableLoader):
     def __init__(self,
-                 file_path: str,
+                 file_path: str = None,
+                 file_content: bytes = None,
                  encoding: Optional[str] = 'utf-8',
                  autodetect_encoding: bool = True,
                  json_documents: bool = True,
@@ -28,11 +29,14 @@ class AlitaCSVLoader(AlitaTableLoader):
                  columns: Optional[List[str]] = None,
                  cleanse: bool = True,
                  **kwargs):
-        super().__init__(file_path=file_path, json_documents=json_documents, columns=columns, raw_content=raw_content, cleanse=cleanse)
+        super().__init__(file_path=file_path, file_content=file_content, json_documents=json_documents, columns=columns, raw_content=raw_content, cleanse=cleanse)
         self.encoding = encoding
         self.autodetect_encoding = autodetect_encoding
-        if autodetect_encoding:
-            self.encoding = from_path(self.file_path).best().encoding
+        if self.file_path:
+            if autodetect_encoding:
+                self.encoding = from_path(self.file_path).best().encoding
+        else:
+            self.encoding = from_bytes(self.file_content).best().encoding
 
     def read_lazy(self) -> Iterator[dict]:
         with open(self.file_path, 'r', encoding=self.encoding) as fd:
@@ -43,7 +47,11 @@ class AlitaCSVLoader(AlitaTableLoader):
                 yield row
 
     def read(self) -> Any:
-        with open(self.file_path, 'r', encoding=self.encoding) as fd:
-            if self.raw_content:
-                return [fd.read()]
-            return list(DictReader(fd))
+        if self.file_path:
+            with open(self.file_path, 'r', encoding=self.encoding) as fd:
+                if self.raw_content:
+                    return [fd.read()]
+                return list(DictReader(fd))
+        else:
+            super.row_content = True
+            return self.file_content
