@@ -5,6 +5,7 @@ from pydantic.fields import Field
 
 from .api_wrapper import GooglePlacesAPIWrapper
 from ..base.tool import BaseAction
+from ..elitea_base import filter_missconfigured_index_tools
 from ..utils import clean_string, TOOLKIT_SPLITTER, get_max_toolkit_length
 from ...configurations.google_places import GooglePlacesConfiguration
 
@@ -45,6 +46,7 @@ class GooglePlacesToolkit(BaseToolkit):
         )
 
     @classmethod
+    @filter_missconfigured_index_tools
     def get_toolkit(cls, selected_tools: list[str] | None = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
